@@ -1,13 +1,13 @@
 import logging
+
 from django.core.management.base import BaseCommand
 
 from ... import __title__
 from ...core.esitools import is_esi_online
-from ...tasks import load_eve_types, _eve_object_names_to_be_loaded
+from ...tasks import _eve_object_names_to_be_loaded, load_eve_types
 from ...utils import LoggerAddTag
 from . import get_input
 
-
 logger = LoggerAddTag(logging.getLogger(__name__), __title__)
 
 
