@@ -2,9 +2,14 @@ from unittest.mock import patch
 
 import requests_mock
 
-from ..core import fuzzwork
+from django.test.utils import override_settings
+
+from ..constants import EveGroupId
+from ..core import evemicros
 from ..models import (
     EveAsteroidBelt,
+    EveCategory,
+    EveGroup,
     EveMoon,
     EvePlanet,
     EveSolarSystem,
@@ -905,13 +910,13 @@ class TestEvePlanetWithSections(NoSocketsTestCase):
         self.assertTrue(obj.enabled_sections.moons)
 
 
-@patch(MODELS_PATH + ".fuzzwork")
+@patch(MODELS_PATH + ".evemicros")
 @patch(MANAGERS_PATH + ".esi")
 class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
-    def test_should_return_stargate(self, mock_esi, mock_fuzzwork):
+    def test_should_return_stargate(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=50016284, name="Stargate (Akidagi)", type_id=16, distance=1000
         )
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
@@ -924,10 +929,10 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         )
         self.assertEqual(result.distance, 1000)
 
-    def test_should_return_planet(self, mock_esi, mock_fuzzwork):
+    def test_should_return_planet(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=40349471, name="Enaluri III", type_id=13, distance=1000
         )
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
@@ -940,10 +945,10 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         )
         self.assertEqual(result.distance, 1000)
 
-    def test_should_return_station(self, mock_esi, mock_fuzzwork):
+    def test_should_return_station(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=60015068,
             name="Enaluri V - State Protectorate Assembly Plant",
             type_id=1529,
@@ -959,10 +964,10 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         )
         self.assertEqual(result.distance, 1000)
 
-    def test_should_return_asteroid_belt(self, mock_esi, mock_fuzzwork):
+    def test_should_return_asteroid_belt(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=40349487, name="Enaluri III - Asteroid Belt 1", type_id=15, distance=1000
         )
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
@@ -978,10 +983,10 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         )
         self.assertEqual(result.distance, 1000)
 
-    def test_should_return_moon(self, mock_esi, mock_fuzzwork):
+    def test_should_return_moon(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=40349472, name="Enaluri III - Moon 1", type_id=14, distance=1000
         )
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
@@ -994,10 +999,10 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         )
         self.assertEqual(result.distance, 1000)
 
-    def test_should_return_none_if_unknown_type(self, mock_esi, mock_fuzzwork):
+    def test_should_return_none_if_unknown_type(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = fuzzwork.EveItem(
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
             id=99, name="Merlin", type_id=603, distance=1000
         )
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
@@ -1006,12 +1011,158 @@ class TestEveSolarSystemNearestCelestial(NoSocketsTestCase):
         # then
         self.assertIsNone(result)
 
-    def test_should_return_none_if_not_found(self, mock_esi, mock_fuzzwork):
+    def test_should_return_none_if_not_found(self, mock_esi, mock_evemicros):
         # given
         mock_esi.client = EsiClientStub()
-        mock_fuzzwork.nearest_celestial.return_value = None
+        mock_evemicros.nearest_celestial.return_value = None
         enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
         # when
         result = enaluri.nearest_celestial(x=-1, y=-2, z=3)
         # then
         self.assertIsNone(result)
+
+    def test_should_return_moon_by_group(self, mock_esi, mock_evemicros):
+        # given
+        mock_esi.client = EsiClientStub()
+        mock_evemicros.nearest_celestial.return_value = evemicros.EveItem(
+            id=40349472, name="Enaluri III - Moon 1", type_id=14, distance=1000
+        )
+        enaluri, _ = EveSolarSystem.objects.get_or_create_esi(id=30045339)
+        # when
+        result = enaluri.nearest_celestial(x=-1, y=-2, z=3, group_id=EveGroupId.MOON)
+        # then
+        self.assertEqual(result.eve_type, EveType.objects.get_or_create_esi(id=14)[0])
+        self.assertEqual(
+            result.eve_object, EveMoon.objects.get_or_create_esi(id=40349472)[0]
+        )
+        self.assertEqual(result.distance, 1000)
+
+
+@override_settings(CELERY_ALWAYS_EAGER=True)
+@patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_GRAPHICS", False)
+@patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_DOGMAS", False)
+@patch(MODELS_PATH + ".EVEUNIVERSE_LOAD_MARKET_GROUPS", False)
+@patch(MANAGERS_PATH + ".esi")
+class EveCategoryUpdateAll(NoSocketsTestCase):
+    def test_should_update_without_children_and_sync(self, mock_esi):
+        # given
+        mock_esi.client = EsiClientStub()
+        # when
+        EveCategory.objects.update_or_create_all_esi(
+            include_children=False, wait_for_children=True
+        )
+        # then
+        self.assertSetEqual(
+            set(EveCategory.objects.values_list("id", flat=True)),
+            {2, 3, 4, 6, 9, 17, 65, 91},
+        )
+        self.assertEqual(EveGroup.objects.count(), 0)
+        self.assertEqual(EveType.objects.count(), 0)
+
+    def test_should_update_with_children_and_sync(self, mock_esi):
+        # given
+        mock_esi.client = EsiClientStub()
+        # when
+        EveCategory.objects.update_or_create_all_esi(
+            include_children=True, wait_for_children=True
+        )
+        # then
+        self.assertSetEqual(
+            set(EveCategory.objects.values_list("id", flat=True)),
+            {2, 3, 4, 6, 9, 17, 65, 91},
+        )
+        self.assertSetEqual(
+            set(EveGroup.objects.values_list("id", flat=True)),
+            {6, 7, 8, 9, 10, 105, 15, 18, 536, 25, 26, 1404, 1950},
+        )
+        self.assertSetEqual(
+            set(EveType.objects.values_list("id", flat=True)),
+            {
+                13,
+                14,
+                15,
+                16,
+                34,
+                35,
+                36,
+                37,
+                38,
+                39,
+                40,
+                34599,
+                950,
+                21947,
+                29627,
+                21949,
+                21951,
+                21953,
+                21955,
+                21957,
+                21959,
+                21961,
+                21967,
+                3800,
+                603,
+                608,
+                2016,
+                621,
+                45038,
+                35825,
+                626,
+                1529,
+            },
+        )
+
+    def test_should_update_with_children_and_async(self, mock_esi):
+        # given
+        mock_esi.client = EsiClientStub()
+        # when
+        EveCategory.objects.update_or_create_all_esi(
+            include_children=True, wait_for_children=False
+        )
+        # then
+        self.assertSetEqual(
+            set(EveCategory.objects.values_list("id", flat=True)),
+            {2, 3, 4, 6, 9, 17, 65, 91},
+        )
+        self.assertSetEqual(
+            set(EveGroup.objects.values_list("id", flat=True)),
+            {6, 7, 8, 9, 10, 105, 15, 18, 536, 25, 26, 1404, 1950},
+        )
+        self.assertSetEqual(
+            set(EveType.objects.values_list("id", flat=True)),
+            {
+                13,
+                14,
+                15,
+                16,
+                34,
+                35,
+                36,
+                37,
+                38,
+                39,
+                40,
+                34599,
+                950,
+                21947,
+                29627,
+                21949,
+                21951,
+                21953,
+                21955,
+                21957,
+                21959,
+                21961,
+                21967,
+                3800,
+                603,
+                608,
+                2016,
+                621,
+                45038,
+                35825,
+                626,
+                1529,
+            },
+        )
